@@ -40,9 +40,12 @@ def color_accounting(val):
     return 'color: %s' % color
 
 
-def generate_table(df: pd.DataFrame, accounting_col_columns: list = None):
+def generate_table(df: pd.DataFrame, precision:int=None, accounting_col_columns: list = None):
     if accounting_col_columns:
         res = (df.style.applymap(color_accounting, subset=accounting_col_columns).set_table_styles(table_style))
     else:
         res = df.style.set_table_styles(table_style)
+
+    if precision:
+        res = res.format(precision=2)
     return res.to_html()
