@@ -11,7 +11,7 @@ class TestCommodplotTable(unittest.TestCase):
         df = pd.DataFrame([[1, 2, 3, 4], [5, 6, 7, 8], [3, -5, 6, 7]], columns=['Foo', 'Bar', 'Buzz', 'Fuzz'],
                           index=['First', 'Second', 'Third'])
 
-        res = cpt.generate_table(df)
+        res = cpt.generate_table(df, accounting_col_columns=['Bar'])
         self.assertIn('<style type="text/css">', res)
 
 
